package swingcolorgame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;

class SwingColorFrame extends JFrame {

    private SwingColorLogic logic;
    private JPanel gamePanel;
    
    public SwingColorFrame(SwingColorLogic logic) {
        this.logic = logic;
        setTitle("Szíkirakós játék");
        setLocation(50,26);
        setDefaultCloseOperation(EXIT_ON_CLOSE);
        setLayout(new BorderLayout());
        
        gamePanel = new JPanel();
        int width = logic.getWidth();
        int height = logic.getHeight();
        gamePanel.setLayout(new GridLayout(width,height) );
        for (int j = 0; j < height; j++){
            for (int i = 0; i < width; i++) {
                JButton jButton = new GameButton(i,j);
                jButton.setPreferredSize(new Dimension(100,100));
                jButton.addActionListener(buttonActionListener);
                gamePanel.add(jButton);
            }
        }
        add(gamePanel,BorderLayout.CENTER);
        setButtonColors();
        
        add(new JButton(newGameAction),BorderLayout.NORTH);
        
        pack();
    }
    
    Action newGameAction = new AbstractAction("Új játék") {

        @Override
        public void actionPerformed(ActionEvent e) {
            logic.newGame();
            setButtonColors();
        }
    };
    
    
    ActionListener buttonActionListener = new ActionListener() {

        @Override
        public void actionPerformed(ActionEvent e) {
            GameButton source = (GameButton) e.getSource();
            int posX = source.getPosX();
            int posY = source.getPosY();
            // +- befejezni
            logic.changeCellColor(posX, posY);
            setButtonColors();
            
        }
    };

    private void setButtonColors() {
        for (Component component : gamePanel.getComponents()) {
             GameButton source = (GameButton) component;
             int posX = source.getPosX();
             int posY = source.getPosY();
             Color color; // 
             int cellInt = logic.getCellColor(posX, posY);
             if(cellInt == 0){
                 color = Color.RED;
             }else if(cellInt == 1){
                 color = Color.CYAN;
             }else{
                 color = Color.GRAY;
             }
             source.setBackground(color);
        }
        boolean isGameWon = logic.isGameWon();
        if(isGameWon){
            JOptionPane.showMessageDialog(this, "Nyertél :)");
            logic.newGame();
            setButtonColors();
        }
    }
    
    
}
